camelot.camelot.view.controls.editors.EmbeddedMany2OneEditor

Package camelot :: Package camelot :: Package view :: Package controls :: Module editors :: Class EmbeddedMany2OneEditor |
[hide private]
[frames] | no frames]

# Class EmbeddedMany2OneEditor

source code

Widget for editing a many 2 one relation a a form embedded in another form.

Instance Methods | [hide private]
__init__(self, admin=None, parent=None, **kwargs) | source code
setEntity(self, entity_instance_getter, propagate=True) | source code